/*
  FUSE: Filesystem in Userspace
  Copyright (C) 2001-2007  Miklos Szeredi <miklos@szeredi.hu>
  Copyright (C) 2011       Sebastian Pipping <sebastian@pipping.org>

  This program can be distributed under the terms of the GNU GPLv2.
  See the file COPYING.
*/

/** @file
 *
 * This file system mirrors the existing file system hierarchy of the
 * system, starting at the root file system. This is implemented by
 * just "passing through" all requests to the corresponding user-space
 * libc functions. This implementation is a little more sophisticated
 * than the one in passthrough.c, so performance is not quite as bad.
 *
 * Compile with:
 *
 *     gcc -Wall passthrough_fh.c `pkg-config fuse3 --cflags --libs` -lulockmgr
 * -o passthrough_fh
 *
 * ## Source code ##
 * \include passthrough_fh.c
 */

#define FUSE_USE_VERSION 31

#define _GNU_SOURCE

#include <fuse3/fuse.h>

#include <stdio.h>
#include <stdlib.h>

#include "fuse_operations.h"
#include "sourcefs.h"
#include "ui-socket.h"

const char *mountpoint = NULL;

int main(int argc, char *argv[]) {
  umask(0);

  // FUSE won't tell us the mountpoint on it's own, so we need to extract it
  // ourselves.
  mountpoint = realpath(argv[argc - 1], NULL);

  int ret = source_init(mountpoint);
  if (ret != 0) {
    perror("source_init");
    exit(EXIT_FAILURE);
  }

  ret = init_ui_socket("/home/fedir/.icfs-sock");
  if (ret != 0) {
    perror("init_ui_socket");
    exit(EXIT_FAILURE);
  }

  ret = fuse_main(argc, argv, get_fuse_operations(), NULL);
  free(mountpoint);
  return ret;
}
